package at.xaxa.ledger.ui

import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Scaffold
import androidx.compose.runtime.Composable
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.navigation.NavType
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.currentBackStackEntryAsState
import androidx.navigation.compose.rememberNavController
import androidx.navigation.navArgument
import at.xaxa.ledger.ui.add.Add
import at.xaxa.ledger.ui.category.add.addCategory
import at.xaxa.ledger.ui.category.edit.EditCategory
import at.xaxa.ledger.ui.edit.Edit
import at.xaxa.ledger.ui.home.Home

enum class AppRoutes(val route: String) {
    Home("home"),
    Add("add"),
    Edit("edit/{entryId}"),
    Category("category"),
    EditCategory("categoryEdit/{categoryId}")
}

@Composable
fun LedgerApp(modifier: Modifier = Modifier){
    val navController = rememberNavController()
    val currentRoute = navController.currentBackStackEntryAsState().value?.destination?.route

    Scaffold() { innerPadding ->
        NavHost(
            navController = navController,
            startDestination = AppRoutes.Home.route,
            modifier = Modifier.padding(innerPadding),
            contentAlignment = Alignment.Center
        ) {
            composable(AppRoutes.Home.route){
                Home(
                    onCardClick = {
                        navController.navigate("edit/$it")
                    },
                    onButtonClick = {
                        navController.navigate("add")
                    },
                    onCatButtonClick = {
                        navController.navigate("category")
                    }
                )
            }

            composable(AppRoutes.Add.route) {
                Add(onCardClick = {
                    navController.navigate("home")
                })
            }
            composable(
                route = AppRoutes.Edit.route,
                arguments = listOf(navArgument("entryId") {
                    type = NavType.IntType
                })
            ) {
                    backStackEntry ->
                Edit(
                    modifier = Modifier,
                    onCardClick = {
                        navController.navigate("home")
                    }
                )
            }
            composable(
                route = AppRoutes.EditCategory.route,
                arguments = listOf(navArgument("categoryId") {
                    type = NavType.IntType
                })
            ) {
                    backStackEntry ->
                EditCategory(
                    modifier = Modifier,
                    onCardClick = {
                        navController.navigate("category")
                    }
                )
            }
            composable(AppRoutes.Category.route){
                addCategory(
                    onButtonClick = {
                        navController.navigate("home")
                    },
                    onCardClick = {
                        navController.navigate("categoryEdit/$it")
                    }
                )
            }
        }
    }
}

